@@ -58,20 +58,30 @@ def renderer_factory(info):
     return PyCTPP2TemplateRenderer(info, engine)
 
 
-class ITranslationSettings(Interface):
+class ITemplateSettings(Interface):
     locales = Attribute("""Locales dictionary""")
+    path = Attribute("""Template path""")
 
     def add_translation(domain, path):
         """Add i18n translation. Bind text domain to locale directory."""
 
+    def add_template_path(path):
+        """Add path to CTPP2 templates."""
+
+
+class PyCTPP2Settings():
+    implements(ITemplateSettings)
 
-class PyCTPP2TranslationSettings(Interface):
     def __init__(self):
         self.locales = {}
+        self.path = []
 
     def add_translation(self, domain, path):
         self.locales[domain] = path
 
+    def add_template_path(self, path):
+        self.path.append(path)
+
 
 class PyCTPP2TemplateRenderer(object):
     '''Renderer for a pyctpp2 template'''
@@ -87,11 +97,10 @@ class PyCTPP2TemplateRenderer(object):
         self.engine.path = self.path
 
         registry = self.info.registry
-        i18n_settings = registry.queryUtility(ITranslationSettings)
-        if i18n_settings:
-            for domain, folder in i18n_settings.locales.items():
-                folder = abspath_from_asset_spec(folder)
-                self.engine.add_translation(domain, folder)
+        self.tmpl_settings = registry.queryUtility(ITemplateSettings)
+        if self.tmpl_settings is None:
+            self.tmpl_settings = PyCTPP2Settings()
+            registry.register(self.tmpl_settings)
 
         domain = info.settings.get('pyctpp2.i18n.domain', '')
         if domain:
@@ -122,6 +131,11 @@ class PyCTPP2TemplateRenderer(object):
 
     @property
     def template(self):
+        if len(self.tmpl_settings.path):
+            tmpl_path = [abspath_from_asset_spec(p) for p in self.tmpl_settings.path]
+            self.engine.path = self.engine.path + tmpl_path
+            self.tmpl_settings.path = []
+
         isabs = os.path.isabs(self.info.name)
 
         filename = self.info.name
@@ -142,6 +156,12 @@ class PyCTPP2TemplateRenderer(object):
         return self.engine.parse(filename)
 
     def __call__(self, value, system):
+        if len(self.tmpl_settings.locales):
+            for domain, folder in self.tmpl_settings.locales.items():
+                folder = abspath_from_asset_spec(folder)
+                self.engine.add_translation(domain, folder)
+            self.tmpl_settings.locales = {}
+
         loc = None
         if 'request' in system:
             loc = get_locale_name(system['request'])
